@@ -16,15 +16,16 @@ class TelescopeFolder(FilesFolder):
         self.uuid = uuid
         super().__init__(context, astronomer, folderpath, '')
 
-    def reset_obscal_folders(self):
-        self.observations_folders = []
-        self.calibrations_folders = []
-
     def walk_telescope_folder(self):
+        known_folderpaths = [o.folderpath for o in self.observations_folders] + \
+                            [o.folderpath for o in self.calibrations_folders]
+
         for name, path in self._walk_folder():
             if not os.path.isdir(path):
                 # If not a directory, skip it. Will skip __oort__.ini files too.
                 continue
+            if path in known_folderpaths:
+                continue
             if name.lower().startswith('calib'):
                 if self.context.debug: print(f' > Found a {self.prefix} {name} folder.')
                 self.calibrations_folders.append(CalibrationsFolder(self.context, self.astronomer, path, name))
